## Badges
![Static Badge](https://img.shields.io/badge/python-100%25-blue)


# hwetests

  

The Hardy-Weinberg Equilibrium (HWE) assumption is essential to many population genetics models, which assumes that allele pairs from a given population are random. An HWE test needs to test whether the pairing are random or not.

Our python package contains three statistical tests for HWE testing:
- **ASTA**
- **UMAT**
- **UMAT with sampling**

Both  **ASTA** and **UMAT with sampling** assume ambiguity in the allele pairing while **UMAT** does not assume ambiguity.

## Table of Contents

-  [Installation](#installation)

-  [Usage](#usage)

-  [Credits](#credits)

-  [License](#license)

## Installation
Use the package manager [pip](https://pip.pypa.io/en/stable/) to install hwetests.
```bash
pip install hwetests
```

## Usage

Here we show how to use our package with simulated data.

### Create data

### ASTA
```python
from hwetests import asta

# returns 'words'
foobar.pluralize('word')

# returns 'geese'
foobar.pluralize('goose')

# returns 'phenomenon'
foobar.singularize('phenomena')
```

## Tests

Go the extra mile and write tests for your application. Then provide examples on how to run them here.

## Badges
![Static Badge](https://img.shields.io/badge/python-100%25-blue)


## License
asasda
